@@ -8,10 +8,10 @@ use warnings;
 use IO::Socket::SSL;
 use REST::Client;
 use Carp;
-use JSON::MaybeXS;
+use JSON::XS;
 use URI;    # The GET requests need URI-escaping
 
-our $VERSION = '0.03_04';
+our $VERSION = '0.01';
 
 sub new {
 	my ($class, %opts) = @_;
@@ -26,7 +26,6 @@ sub new {
 		ua => REST::Client->new (
 			{   host    => 'https://api.abuseipdb.com',
 				timeout => $opts{timeout} // 20,
-				agent   => "WebService::AbuseIPDB/$VERSION",
 
 #			useragent => LWP::UserAgent->new (ssl_opts => {
 #					verify_hostname => 1,
@@ -52,7 +51,7 @@ sub _send_receive {
 		Accept => 'application/json',
 		Key    => $self->{key}
 	};
-	if ($meth eq 'GET') {
+	if ($meth eq 'GET' && $data) {
 		my $u = URI->new ($path);
 		$u->query_form (%$data);
 		$path = $u->as_string;
@@ -69,32 +68,19 @@ sub _send_receive {
 			croak "Unrecognised method '$meth'";
 		}
 
-		if ($self->{ua}->responseCode !~ /400|50./) {
+		if ($self->{ua}->responseCode !~ /[45]00/) {
 			return decode_json $self->{ua}->responseContent
 			  if $self->{ua}->responseHeader ('Content-type') eq
 			  'application/json';
 			return undef;
 		}
 		$tries_left--;
-		warn "REST error " . $self->{ua}->responseCode;
+		carp "REST error " . $self->{ua}->responseCode;
 	}
 
-	if ($self->{ua}->responseCode > 499) {
-		# Not our problem, so don't carp
-		return {
-			errors => [{
-				status => $self->{ua}->responseCode,
-				detail => $self->{ua}->responseContent //
-					'Server Problem'
-			}]
-		};
-	}
-
-	carp "Problem with $meth $path\nData was " . encode_json ($data) .
-		"\nClient warning: " .
-		(	$self->{ua}->responseHeader ('Client-Warning') //
-			$self->{ua}->responseContent //
-			$self->{ua}->responseCode);
+	carp "Problem with $meth $path";
+	carp "Data was " . encode_json ($data) if defined $data;
+	carp "Client warning: ", $self->{ua}->responseHeader ('Client-Warning');
 	return undef;
 }
 
@@ -112,21 +98,7 @@ sub check {
 	require WebService::AbuseIPDB::CheckResponse;
 	return WebService::AbuseIPDB::CheckResponse->new (
 		$self->_send_receive ('GET', 'check', $data));
-}
 
-sub check_block {
-	my ($self, %args) = @_;
-	unless (exists $args{ip}) {
-		carp "No IP in argument hash";
-		return;
-	}
-
-	# Validate this here TODO
-	my $data = {network => $args{ip}};
-	$data->{maxAgeInDays} = $args{max_age} if exists $args{max_age};
-	require WebService::AbuseIPDB::CheckBlockResponse;
-	return WebService::AbuseIPDB::CheckBlockResponse->new (
-		$self->_send_receive ('GET', 'check-block', $data));
 }
 
 sub report {
@@ -158,48 +130,6 @@ sub report {
 		$self->_send_receive ('POST', 'report', $data));
 }
 
-sub blacklist {
-	my ($self, %args) = @_;
-	my $data = {
-		limit => 1000,
-		confidenceMinimum => 75
-	};
-
-	if (exists $args{limit}) {
-		unless ($args{limit} =~ /^[0-9]+$/) {
-			carp "limit must be a whole number";
-			return;
-		}
-		if ($args{limit} < 1) {
-			carp "limit must be greater than zero";
-			return;
-		}
-		$data->{limit} = $args{limit};
-	}
-
-	if (exists $args{min_abuse}) {
-		unless ($args{min_abuse} =~ /^[0-9]+$/) {
-			carp "min_abuse must be a whole number";
-			return;
-		}
-		if ($args{min_abuse} < 25) {
-			carp "min_abuse is $args{min_abuse} but must be greater than 24";
-			return;
-		}
-		if ($args{min_abuse} > 100) {
-			carp "min_abuse is $args{min_abuse} but must be less than 100";
-			return;
-		}
-		$data->{confidenceMinimum} = $args{min_abuse};
-	}
-
-	require WebService::AbuseIPDB::BlacklistResponse;
-	require WebService::AbuseIPDB::BlacklistMember;
-	return WebService::AbuseIPDB::BlacklistResponse->new (
-		$self->_send_receive ('GET', 'blacklist', $data));
-
-}
-
 1;
 
 __END__
@@ -213,6 +143,10 @@ __END__
 
 WebService::AbuseIPDB - Client for the API (version 2) of AbuseIPDB
 
+=head1 VERSION
+
+Version 0.00
+
 =head1 SYNOPSIS
 
     use WebService::AbuseIPDB;
@@ -225,7 +159,7 @@ WebService::AbuseIPDB - Client for the API (version 2) of AbuseIPDB
 
 =head1 DESCRIPTION
 
-L<AbuseIPDB|https://www.abuseipdb.com/> maintains a database of reports
+L<https://www.abuseipdb.com/|AbuseIPDB> maintains a database of reports
 of bad actors on the net. Users may interface with the database through
 a web browser using forms on their site. An alternative is to use their
 API. Version 1 of this API is to be retired in 2020. This module serves
@@ -235,7 +169,7 @@ as a client for Version 2 of the API.
 
 =head2 new
 
-    my $ipdb = WebService::AbuseIPDB->new (%opts);
+	my $ipdb = WebService::AbuseIPDB->new (%opts);
 
 The constructor takes a hash of configuration details.
 
@@ -256,15 +190,6 @@ using this module.
 The timeout in seconds to wait for the server to respond. Defaults to
 20.
 
-Note that the way that L<IO::Socket::IP> handles this in modern
-versions (0.32 and above) means that the timeout applies for each IP
-address which the host resolves to. At time of writing (July 2020) for
-L<api.abuseipdb.com|https://www.sitechecks.co.uk/ipcheck.cgi?in=api.abuseipdb.com>
-there are three IPv4 addresses and three IPv6 addresses so the 20 second
-timeout will apply to each of them consecutively in each supported IP
-family meaning that if all are down you might be waiting for as much as
-2 minutes for a response.
-
 =item retry
 
 The number of times to retry on timeout or network error. Defaults to 0
@@ -274,7 +199,7 @@ The number of times to retry on timeout or network error. Defaults to 0
 
 =head2 check
 
-    my $res = $ipdb->check (ip => '127.0.0.2', max_age => 90);
+	my $res = $ipdb->check (ip => '127.0.0.2', max_age => 90);
 
 This uses the C<check> endpoint and returns a
 L<WebService::AbuseIPDB::CheckResponse> object to access the data held
@@ -299,31 +224,6 @@ B<Not yet impelemented>.
 
 =back
 
-
-=head2 check_block
-
-    my $res = $ipdb->check_block (ip => '127.0.0.0/29', max_age => 30);
-
-This uses the C<check-block> endpoint and returns a
-L<WebService::AbuseIPDB::CheckBlockResponse> object to access the data held
-in the database for the provided IP address range. The argument is a hash with
-these keys:
-
-=over
-
-=item ip
-
-The IP range to be checked in
-L<CIDR|https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing>
-format. This item is mandatory.
-
-=item max_age
-
-The age in integral days of the oldest report(s) to include. If
-omitted the server default is used (currently 30).
-
-=back
-
 =head2 report
 
     my $res = $ipdb->report (
@@ -359,39 +259,6 @@ and should be decoded.
 The method will return undef on client error and a
 WebService::AbuseIPDB::ReportResponse object otherwise.
 
-=head2 blacklist
-
-    my $res = $ipdb->blacklist (
-        min_abuse   => 90,
-        limit       => 1000
-    );
-    print "As at " . $res->as_at . "\n";
-    for my $bad ($res->list) {
-        printf "Address %s has score %i%%\n", $bad->ip, $bad->score;
-    }
-
-This uses the C<blacklist> endpoint to retrieve a list of abusive
-addresses. It takes a single hash as the only argument with these
-elements:
-
-=over 4
-
-=item min_abuse
-
-Only include addresses with an abuse confidence score of this level or
-higher. Minimum is 25, maximum is 100 and default is 75.
-
-=item limit
-
-An integer giving the maximum quantity of addresses to return. Minimum
-is 1, maximum is 10,000 for non-subscribers and default is 1000.
-
-=back
-
-The method will return undef on client error and a
-WebService::AbuseIPDB::BlacklistResponse object otherwise.
-
-
 =head1 STABILITY
 
 This is currently alpha software. Be aware that both the internals and
@@ -401,8 +268,7 @@ the interface are liable to change.
 
 Implement the C<verbose> option on the check method.
 
-Add the bulk-report API endpoints. Allow for fast
-blacklist-as-string response too.
+Add the other API endpoints: check-block, bulk-report, blacklist.
 
 More validation/sanitation of inputs.
 
@@ -414,19 +280,14 @@ L<SendMail::AbuseIPDB> is a client for v1 of the API.
 
 Full documentation for the API is at L<https://docs.abuseipdb.com/>.
 
-Discussion of the IO::Socket::IP timeout can be found in
-L<RT 92075|https://rt.cpan.org/Public/Bug/Display.html?id=92075>.
-
 =head1 AUTHOR
 
 Pete Houston, C<< <cpan at openstrike.co.uk> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-webservice-abuseipdb at rt.cpan.org>, or through the web interface at
-L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.
-See the file CONTRIBUTING.md for further details.
+Please report any bugs or feature requests to C<bug-webservice-abuseipdb at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.  See the file CONTRIBUTING.md for further details.
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -435,7 +296,7 @@ API.
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright © 2020-2025 Pete Houston.
+Copyright © 2020 Pete Houston.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
